@@ -4,6 +4,7 @@ plt.style.use('seaborn')
 from matplotlib.gridspec import GridSpec
 import sys
 import pandas as pd
+from pathlib import Path
 
 import pyemission as pe
 
@@ -33,22 +34,24 @@ class Car:
         print('Loading Data...\n')
         df = Util.read_data(excel_file_name, sheet_name)
         vehicle = df.vehicle_type[0]
-        
-        # find the path of the 'db.pkl' to load it
-        path = pe.__file__
-        length = len('__init__.py')
-        path = path[:-length]
-        db_path = path + 'db.pkl'
+
+        my_file = Path('db.pkl')
+        if my_file.is_file(): # check if the file exists in the current directory
+            db_path = 'db.pkl'
+        else: # find the path of the 'db.pkl' to load it
+            try:
+                path = pe.__file__
+                length = len('__init__.py')
+                path = path[:-length]
+                db_path = path + 'db.pkl'
+            except:
+                print('Could not load the file: db.pkl\nMake sure the current working directory contains this file.')
+                
         if vehicle == 'Light commercial truck' :
-            try:
-                df_emission_rate = pickle.load(open(db_path,'rb'))[0]
-            except:
-                print('Could not load the file: db.pkl\nMake sure the working directory contains this file.')
+            df_emission_rate = pickle.load(open(db_path,'rb'))[0]
+
         else:
-            try:
-                df_emission_rate = pickle.load(open(db_path,'rb'))[1]
-            except:
-                print('Could not load the file: db.pkl\nMake sure the working directory contains this file.')
+            df_emission_rate = pickle.load(open(db_path,'rb'))[1]
         
         # VSP coefficients
         A, B, C, f = Util.vsp_coeff(vehicle)
